@@ -2,9 +2,14 @@ use rulex_macro::rulex;
 
 #[test]
 fn rust() {
-    const REGEX: &str = rulex!("foo" | "bar"?);
+    const REGEX: &str = rulex! {
+        // variables
+        let number = '-'? [d]+;
+        let op = ["+-*/"];
+        number (op number)*
+    };
 
-    assert_eq!(REGEX, "foo|(?:bar)??");
+    assert_eq!(REGEX, "-?\\d+(?:[+\\-*/]-?\\d+)*");
 }
 
 #[test]
